# Aracnid Core

This package provides abstract interfaces and shared types for building Aracnid-compatible data connectors.

## Getting Started

These instructions will get you a copy of the project up and running on your local machine for development and testing purposes.

### Prerequisites

This package supports the following version of Python:

- Python 3.10 or later

### Installing

Install the latest package using pip. (We prefer poetry.)

```
$ poetry install aracnid-core
```

## Running the tests

Explain how to run the automated tests for this system

```
$ python -m pytest
```

## Usage

TODO

## Authors

- **Jason Romano** - [Aracnid](https://github.com/aracnid)

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details
